[llvm-commits] CVS: llvm/include/llvm/Value.h

Chris Lattner lattner at cs.uiuc.edu
Sun Jul 18 17:57:50 PDT 2004



Changes in directory llvm/include/llvm:

Value.h updated: 1.59 -> 1.60

---
Log message:

Add new enum entries for ConstantAggregateZeroVal/ConstantExprVal and
rename ConstantVal to SimpleConstantVal


---
Diffs of the changes:  (+12 -8)

Index: llvm/include/llvm/Value.h
diff -u llvm/include/llvm/Value.h:1.59 llvm/include/llvm/Value.h:1.60
--- llvm/include/llvm/Value.h:1.59	Sat Jul 17 19:56:58 2004
+++ llvm/include/llvm/Value.h	Sun Jul 18 19:57:40 2004
@@ -122,13 +122,15 @@
   /// (and Instruction must be last).
   ///
   enum ValueTy {
-    ArgumentVal,            // This is an instance of Argument
-    BasicBlockVal,          // This is an instance of BasicBlock
-    FunctionVal,            // This is an instance of Function
-    GlobalVariableVal,      // This is an instance of GlobalVariable
-    ConstantVal,            // This is an instance of Constant
-    InstructionVal,         // This is an instance of Instruction
-    ValueListVal            // This is for bcreader, a special ValTy
+    ArgumentVal,              // This is an instance of Argument
+    BasicBlockVal,            // This is an instance of BasicBlock
+    FunctionVal,              // This is an instance of Function
+    GlobalVariableVal,        // This is an instance of GlobalVariable
+    ConstantExprVal,          // This is an instance of ConstantExpr
+    ConstantAggregateZeroVal, // This is an instance of ConstantAggregateNull
+    SimpleConstantVal,        // This is some other type of Constant
+    InstructionVal,           // This is an instance of Instruction
+    ValueListVal              // This is for bcreader, a special ValTy
   };
   unsigned getValueType() const {
     return SubclassID;
@@ -178,7 +180,9 @@
 // the subtype header files to test to see if the value is a subclass...
 //
 template <> inline bool isa_impl<Constant, Value>(const Value &Val) { 
-  return Val.getValueType() == Value::ConstantVal ||
+  return Val.getValueType() == Value::ConstantExprVal ||
+         Val.getValueType() == Value::SimpleConstantVal ||
+         Val.getValueType() == Value::ConstantAggregateZeroVal ||
          Val.getValueType() == Value::FunctionVal ||
 	 Val.getValueType() == Value::GlobalVariableVal;
 }





More information about the llvm-commits mailing list